@@ -1,4 +1,3 @@
-
 from quickbase_client.query.ast import after_
 from quickbase_client.query.ast import and_
 from quickbase_client.query.ast import before_
@@ -23,25 +22,25 @@ from quickbase_client.query.ast import true_
 
 
 __all__ = [
-    'or_',
-    'and_',
-    'contains_',
-    'not_contains_',
-    'has_',
-    'not_has_',
-    'eq_',
-    'true_',
-    'not_eq_',
-    'starts_with_',
-    'not_starts_width_',
-    'before_',
-    'on_or_before_',
-    'after_',
-    'on_or_after_',
-    'during_',
-    'not_during_',
-    'lt_',
-    'lte_',
-    'gt_',
-    'gte_'
+    "or_",
+    "and_",
+    "contains_",
+    "not_contains_",
+    "has_",
+    "not_has_",
+    "eq_",
+    "true_",
+    "not_eq_",
+    "starts_with_",
+    "not_starts_width_",
+    "before_",
+    "on_or_before_",
+    "after_",
+    "on_or_after_",
+    "during_",
+    "not_during_",
+    "lt_",
+    "lte_",
+    "gt_",
+    "gte_",
 ]
