@@ -1,5 +1,3 @@
 from quickbase_client.tools.log_handler import QuickbaseLogHandler
 
-__all__ = [
-    'QuickbaseLogHandler'
-]
+__all__ = ["QuickbaseLogHandler"]
